==> jc-1.4.0.tar.gz: soot/AbstractValueBox.h <==
// public abstract class soot.AbstractValueBox

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 95b491953cb1508e soot_AbstractValueBox
// @dep_class 6ddedfee878f127 soot_tagkit_AbstractHost

// header file dependencies
// @dep_header soot_tagkit_AbstractHost

#include "soot/tagkit/AbstractHost.h"

#ifndef _JC_soot_AbstractValueBox_H_
#define _JC_soot_AbstractValueBox_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_UnitPrinter$object;
struct _jc_soot_Value$object;

// Typedefs
typedef struct _jc_soot_AbstractValueBox$sub_refs	_jc_soot_AbstractValueBox$sub_refs;
typedef struct _jc_soot_AbstractValueBox$sub_nonrefs	_jc_soot_AbstractValueBox$sub_nonrefs;
typedef struct _jc_soot_AbstractValueBox$refs	_jc_soot_AbstractValueBox$refs;
typedef struct _jc_soot_AbstractValueBox$nonrefs	_jc_soot_AbstractValueBox$nonrefs;
typedef struct _jc_soot_AbstractValueBox$object	_jc_soot_AbstractValueBox$object;

typedef const struct _jc_soot_AbstractValueBox$vmethods	_jc_soot_AbstractValueBox$vmethods;
typedef const struct _jc_soot_AbstractValueBox$vtable	_jc_soot_AbstractValueBox$vtable;
typedef const struct _jc_soot_AbstractValueBox$vtype	_jc_soot_AbstractValueBox$vtype;

// Constructors
extern void _jc_soot_AbstractValueBox$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_AbstractValueBox$object *);

// Virtual methods
extern struct _jc_object *_jc_soot_AbstractValueBox$method$getValue$5c68332c5d4a9bf9(_jc_env *, struct _jc_soot_AbstractValueBox$object *);
extern void _jc_soot_AbstractValueBox$method$setValue$f9a819a454867ebc(_jc_env *, struct _jc_soot_AbstractValueBox$object *, struct _jc_object *);
extern void _jc_soot_AbstractValueBox$method$toString$49ce0d4a4e59c2a6(_jc_env *, struct _jc_soot_AbstractValueBox$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_AbstractValueBox$method_info$getValue$5c68332c5d4a9bf9;
extern _jc_method _jc_soot_AbstractValueBox$method_info$setValue$f9a819a454867ebc;
extern _jc_method _jc_soot_AbstractValueBox$method_info$toString$49ce0d4a4e59c2a6;

// Virtual methods structure
struct _jc_soot_AbstractValueBox$vmethods {
	struct _jc_object	*(*getValue$5c68332c5d4a9bf9)(_jc_env *, struct _jc_soot_AbstractValueBox$object *);
	void	(*setValue$f9a819a454867ebc)(_jc_env *, struct _jc_soot_AbstractValueBox$object *, struct _jc_object *);
	void	(*toString$49ce0d4a4e59c2a6)(_jc_env *, struct _jc_soot_AbstractValueBox$object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_AbstractValueBox$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_AbstractHost$vmethods	soot_tagkit_AbstractHost;
	_jc_soot_AbstractValueBox$vmethods	soot_AbstractValueBox;
};

// Vtype
struct _jc_soot_AbstractValueBox$vtype {
	_jc_type			type;
	_jc_soot_AbstractValueBox$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_AbstractValueBox$sub_refs {
	struct _jc_object	*value;
};

// Reference instance fields (object)
struct _jc_soot_AbstractValueBox$refs {
    _jc_soot_AbstractValueBox$sub_refs	soot_AbstractValueBox;
    _jc_soot_tagkit_AbstractHost$sub_refs	soot_tagkit_AbstractHost;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_AbstractValueBox$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_AbstractValueBox$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_AbstractHost$sub_nonrefs	soot_tagkit_AbstractHost;
    _jc_soot_AbstractValueBox$sub_nonrefs	soot_AbstractValueBox;
};

// Object instance structure
struct _jc_soot_AbstractValueBox$object {
	_jc_soot_AbstractValueBox$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_AbstractValueBox$vtype	*vtype;
	_jc_soot_AbstractValueBox$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_AbstractValueBox$vtype _jc_soot_AbstractValueBox$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_AbstractValueBox, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_AbstractValueBox$class_object;

#endif	/* _JC_soot_AbstractValueBox_H_ */

==> jc-1.4.6.tar.gz: soot/AbstractValueBox.h <==
// public abstract class soot.AbstractValueBox

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 95b491953cb1508e soot_AbstractValueBox
// @dep_class 6ddedfee878f127 soot_tagkit_AbstractHost

// header file dependencies
// @dep_header soot_tagkit_AbstractHost

#include "soot/tagkit/AbstractHost.h"

#ifndef _JC_soot_AbstractValueBox_H_
#define _JC_soot_AbstractValueBox_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_UnitPrinter$object;
struct _jc_soot_Value$object;

// Typedefs
typedef struct _jc_soot_AbstractValueBox$sub_refs	_jc_soot_AbstractValueBox$sub_refs;
typedef struct _jc_soot_AbstractValueBox$sub_nonrefs	_jc_soot_AbstractValueBox$sub_nonrefs;
typedef struct _jc_soot_AbstractValueBox$refs	_jc_soot_AbstractValueBox$refs;
typedef struct _jc_soot_AbstractValueBox$nonrefs	_jc_soot_AbstractValueBox$nonrefs;
typedef struct _jc_soot_AbstractValueBox$object	_jc_soot_AbstractValueBox$object;

typedef const struct _jc_soot_AbstractValueBox$vmethods	_jc_soot_AbstractValueBox$vmethods;
typedef const struct _jc_soot_AbstractValueBox$vtable	_jc_soot_AbstractValueBox$vtable;
typedef const struct _jc_soot_AbstractValueBox$vtype	_jc_soot_AbstractValueBox$vtype;

// Constructors
extern void _jc_soot_AbstractValueBox$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_AbstractValueBox$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_soot_AbstractValueBox$method$getValue$5c68332c5d4a9bf9(_jc_env *, struct _jc_soot_AbstractValueBox$object *) _JC_JCNI_ATTR;
extern void _jc_soot_AbstractValueBox$method$setValue$f9a819a454867ebc(_jc_env *, struct _jc_soot_AbstractValueBox$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_soot_AbstractValueBox$method$toString$49ce0d4a4e59c2a6(_jc_env *, struct _jc_soot_AbstractValueBox$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_AbstractValueBox$method_info$getValue$5c68332c5d4a9bf9;
extern _jc_method _jc_soot_AbstractValueBox$method_info$setValue$f9a819a454867ebc;
extern _jc_method _jc_soot_AbstractValueBox$method_info$toString$49ce0d4a4e59c2a6;

// Virtual methods structure
struct _jc_soot_AbstractValueBox$vmethods {
	struct _jc_object	*(*getValue$5c68332c5d4a9bf9)(_jc_env *, struct _jc_soot_AbstractValueBox$object *) _JC_JCNI_ATTR;
	void	(*setValue$f9a819a454867ebc)(_jc_env *, struct _jc_soot_AbstractValueBox$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*toString$49ce0d4a4e59c2a6)(_jc_env *, struct _jc_soot_AbstractValueBox$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_AbstractValueBox$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_AbstractHost$vmethods	soot_tagkit_AbstractHost;
	_jc_soot_AbstractValueBox$vmethods	soot_AbstractValueBox;
};

// Vtype
struct _jc_soot_AbstractValueBox$vtype {
	_jc_type			type;
	_jc_soot_AbstractValueBox$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_AbstractValueBox$sub_refs {
	struct _jc_object	*value;
};

// Reference instance fields (object)
struct _jc_soot_AbstractValueBox$refs {
    _jc_soot_AbstractValueBox$sub_refs	soot_AbstractValueBox;
    _jc_soot_tagkit_AbstractHost$sub_refs	soot_tagkit_AbstractHost;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_AbstractValueBox$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_AbstractValueBox$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_AbstractHost$sub_nonrefs	soot_tagkit_AbstractHost;
    _jc_soot_AbstractValueBox$sub_nonrefs	soot_AbstractValueBox;
};

// Object instance structure
struct _jc_soot_AbstractValueBox$object {
	_jc_soot_AbstractValueBox$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_AbstractValueBox$vtype	*vtype;
	_jc_soot_AbstractValueBox$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_AbstractValueBox$vtype _jc_soot_AbstractValueBox$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_AbstractValueBox, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_AbstractValueBox$class_object;

#endif	/* _JC_soot_AbstractValueBox_H_ */
